@@ -212,6 +212,8 @@ class Document(proto.Message):
             form_fields (Sequence[google.cloud.documentai_v1.types.Document.Page.FormField]):
                 A list of visually detected form fields on
                 the page.
+            provenance (google.cloud.documentai_v1.types.Document.Provenance):
+                The history of this page.
         """
 
         class Dimension(proto.Message):
@@ -552,6 +554,8 @@ class Document(proto.Message):
                     -  blank (this indicates the field_value is normal text)
                     -  "unfilled_checkbox"
                     -  "filled_checkbox".
+                provenance (google.cloud.documentai_v1.types.Document.Provenance):
+                    The history of this annotation.
             """
 
             field_name = proto.Field(
@@ -567,6 +571,9 @@ class Document(proto.Message):
                 proto.MESSAGE, number=4, message="Document.Page.DetectedLanguage",
             )
             value_type = proto.Field(proto.STRING, number=5,)
+            provenance = proto.Field(
+                proto.MESSAGE, number=8, message="Document.Provenance",
+            )
 
         class DetectedLanguage(proto.Message):
             r"""Detected language for a structural component.
@@ -615,6 +622,9 @@ class Document(proto.Message):
         form_fields = proto.RepeatedField(
             proto.MESSAGE, number=11, message="Document.Page.FormField",
         )
+        provenance = proto.Field(
+            proto.MESSAGE, number=16, message="Document.Provenance",
+        )
 
     class Entity(proto.Message):
         r"""A phrase in the text that is a known entity type, such as a
@@ -819,7 +829,9 @@ class Document(proto.Message):
                     Required. Index into the
                     [Document.pages][google.cloud.documentai.v1.Document.pages]
                     element, for example using [Document.pages][page_refs.page]
-                    to locate the related page element.
+                    to locate the related page element. This field is skipped
+                    when its value is the default 0. See
+                    https://developers.google.com/protocol-buffers/docs/proto3#json.
                 layout_type (google.cloud.documentai_v1.types.Document.PageAnchor.PageRef.LayoutType):
                     Optional. The type of the layout element that
                     is being referenced if any.
@@ -899,11 +911,16 @@ class Document(proto.Message):
                 revision (int):
                     The index of the [Document.revisions] identifying the parent
                     revision.
+                index (int):
+                    The index of the parent revisions
+                    corresponding collection of items (eg. list of
+                    entities, properties within entities, etc.)
                 id (int):
                     The id of the parent provenance.
             """
 
             revision = proto.Field(proto.INT32, number=1,)
+            index = proto.Field(proto.INT32, number=3,)
             id = proto.Field(proto.INT32, number=2,)
 
         revision = proto.Field(proto.INT32, number=1,)
