@@ -31,7 +31,8 @@ class Vertex(proto.Message):
         x (int):
             X coordinate.
         y (int):
-            Y coordinate.
+            Y coordinate (starts from the top of the
+            image).
     """
 
     x = proto.Field(proto.INT32, number=1,)
@@ -47,7 +48,8 @@ class NormalizedVertex(proto.Message):
         x (float):
             X coordinate.
         y (float):
-            Y coordinate.
+            Y coordinate (starts from the top of the
+            image).
     """
 
     x = proto.Field(proto.FLOAT, number=1,)
