@@ -25,8 +25,10 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.documentai_v1beta3.types import document_processor_service
+from google.cloud.documentai_v1beta3.types import processor as gcd_processor
 from google.longrunning import operations_pb2  # type: ignore
 
 try:
@@ -47,8 +49,6 @@ except AttributeError:
     except pkg_resources.DistributionNotFound:  # pragma: NO COVER
         _GOOGLE_AUTH_VERSION = None
 
-_API_CORE_VERSION = google.api_core.__version__
-
 
 class DocumentProcessorServiceTransport(abc.ABC):
     """Abstract transport class for DocumentProcessorService."""
@@ -66,6 +66,7 @@ class DocumentProcessorServiceTransport(abc.ABC):
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -89,6 +90,8 @@ class DocumentProcessorServiceTransport(abc.ABC):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
@@ -98,7 +101,7 @@ class DocumentProcessorServiceTransport(abc.ABC):
         scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
 
         # Save the scopes.
-        self._scopes = scopes or self.AUTH_SCOPES
+        self._scopes = scopes
 
         # If no credentials are provided, then determine the appropriate
         # defaults.
@@ -117,13 +120,20 @@ class DocumentProcessorServiceTransport(abc.ABC):
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials is service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
-    # TODO(busunkim): These two class methods are in the base transport
+    # TODO(busunkim): This method is in the base transport
     # to avoid duplicating code across the transport classes. These functions
-    # should be deleted once the minimum required versions of google-api-core
-    # and google-auth are increased.
+    # should be deleted once the minimum required versions of google-auth is increased.
 
     # TODO: Remove this function once google-auth >= 1.25.0 is required
     @classmethod
@@ -144,27 +154,6 @@ class DocumentProcessorServiceTransport(abc.ABC):
 
         return scopes_kwargs
 
-    # TODO: Remove this function once google-api-core >= 1.26.0 is required
-    @classmethod
-    def _get_self_signed_jwt_kwargs(
-        cls, host: str, scopes: Optional[Sequence[str]]
-    ) -> Dict[str, Union[Optional[Sequence[str]], str]]:
-        """Returns kwargs to pass to grpc_helpers.create_channel depending on the google-api-core version"""
-
-        self_signed_jwt_kwargs: Dict[str, Union[Optional[Sequence[str]], str]] = {}
-
-        if _API_CORE_VERSION and (
-            packaging.version.parse(_API_CORE_VERSION)
-            >= packaging.version.parse("1.26.0")
-        ):
-            self_signed_jwt_kwargs["default_scopes"] = cls.AUTH_SCOPES
-            self_signed_jwt_kwargs["scopes"] = scopes
-            self_signed_jwt_kwargs["default_host"] = cls.DEFAULT_HOST
-        else:
-            self_signed_jwt_kwargs["scopes"] = scopes or cls.AUTH_SCOPES
-
-        return self_signed_jwt_kwargs
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -198,6 +187,26 @@ class DocumentProcessorServiceTransport(abc.ABC):
                 default_timeout=120.0,
                 client_info=client_info,
             ),
+            self.fetch_processor_types: gapic_v1.method.wrap_method(
+                self.fetch_processor_types,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.list_processors: gapic_v1.method.wrap_method(
+                self.list_processors, default_timeout=None, client_info=client_info,
+            ),
+            self.create_processor: gapic_v1.method.wrap_method(
+                self.create_processor, default_timeout=None, client_info=client_info,
+            ),
+            self.delete_processor: gapic_v1.method.wrap_method(
+                self.delete_processor, default_timeout=None, client_info=client_info,
+            ),
+            self.enable_processor: gapic_v1.method.wrap_method(
+                self.enable_processor, default_timeout=None, client_info=client_info,
+            ),
+            self.disable_processor: gapic_v1.method.wrap_method(
+                self.disable_processor, default_timeout=None, client_info=client_info,
+            ),
             self.review_document: gapic_v1.method.wrap_method(
                 self.review_document,
                 default_retry=retries.Retry(
@@ -241,6 +250,66 @@ class DocumentProcessorServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def fetch_processor_types(
+        self,
+    ) -> Callable[
+        [document_processor_service.FetchProcessorTypesRequest],
+        Union[
+            document_processor_service.FetchProcessorTypesResponse,
+            Awaitable[document_processor_service.FetchProcessorTypesResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_processors(
+        self,
+    ) -> Callable[
+        [document_processor_service.ListProcessorsRequest],
+        Union[
+            document_processor_service.ListProcessorsResponse,
+            Awaitable[document_processor_service.ListProcessorsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def create_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.CreateProcessorRequest],
+        Union[gcd_processor.Processor, Awaitable[gcd_processor.Processor]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def delete_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.DeleteProcessorRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def enable_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.EnableProcessorRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def disable_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.DisableProcessorRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def review_document(
         self,
