@@ -26,6 +26,7 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.documentai_v1beta3.types import document_processor_service
+from google.cloud.documentai_v1beta3.types import processor as gcd_processor
 from google.longrunning import operations_pb2  # type: ignore
 from .base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
 
@@ -63,6 +64,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
@@ -103,6 +105,8 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
           google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -156,6 +160,7 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -211,14 +216,14 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
               and ``credentials_file`` are passed.
         """
 
-        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
-
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
             quota_project_id=quota_project_id,
-            **self_signed_jwt_kwargs,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -300,6 +305,180 @@ class DocumentProcessorServiceGrpcTransport(DocumentProcessorServiceTransport):
             )
         return self._stubs["batch_process_documents"]
 
+    @property
+    def fetch_processor_types(
+        self,
+    ) -> Callable[
+        [document_processor_service.FetchProcessorTypesRequest],
+        document_processor_service.FetchProcessorTypesResponse,
+    ]:
+        r"""Return a callable for the fetch processor types method over gRPC.
+
+        Fetches processor types.
+
+        Returns:
+            Callable[[~.FetchProcessorTypesRequest],
+                    ~.FetchProcessorTypesResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "fetch_processor_types" not in self._stubs:
+            self._stubs["fetch_processor_types"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/FetchProcessorTypes",
+                request_serializer=document_processor_service.FetchProcessorTypesRequest.serialize,
+                response_deserializer=document_processor_service.FetchProcessorTypesResponse.deserialize,
+            )
+        return self._stubs["fetch_processor_types"]
+
+    @property
+    def list_processors(
+        self,
+    ) -> Callable[
+        [document_processor_service.ListProcessorsRequest],
+        document_processor_service.ListProcessorsResponse,
+    ]:
+        r"""Return a callable for the list processors method over gRPC.
+
+        Lists all processors which belong to this project.
+
+        Returns:
+            Callable[[~.ListProcessorsRequest],
+                    ~.ListProcessorsResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_processors" not in self._stubs:
+            self._stubs["list_processors"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/ListProcessors",
+                request_serializer=document_processor_service.ListProcessorsRequest.serialize,
+                response_deserializer=document_processor_service.ListProcessorsResponse.deserialize,
+            )
+        return self._stubs["list_processors"]
+
+    @property
+    def create_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.CreateProcessorRequest], gcd_processor.Processor
+    ]:
+        r"""Return a callable for the create processor method over gRPC.
+
+        Creates a processor from the type processor that the
+        user chose. The processor will be at "ENABLED" state by
+        default after its creation.
+
+        Returns:
+            Callable[[~.CreateProcessorRequest],
+                    ~.Processor]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "create_processor" not in self._stubs:
+            self._stubs["create_processor"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/CreateProcessor",
+                request_serializer=document_processor_service.CreateProcessorRequest.serialize,
+                response_deserializer=gcd_processor.Processor.deserialize,
+            )
+        return self._stubs["create_processor"]
+
+    @property
+    def delete_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.DeleteProcessorRequest], operations_pb2.Operation
+    ]:
+        r"""Return a callable for the delete processor method over gRPC.
+
+        Deletes the processor, unloads all deployed model
+        artifacts if it was enabled and then deletes all
+        artifacts associated with this processor.
+
+        Returns:
+            Callable[[~.DeleteProcessorRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_processor" not in self._stubs:
+            self._stubs["delete_processor"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/DeleteProcessor",
+                request_serializer=document_processor_service.DeleteProcessorRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["delete_processor"]
+
+    @property
+    def enable_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.EnableProcessorRequest], operations_pb2.Operation
+    ]:
+        r"""Return a callable for the enable processor method over gRPC.
+
+        Enables a processor
+
+        Returns:
+            Callable[[~.EnableProcessorRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "enable_processor" not in self._stubs:
+            self._stubs["enable_processor"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/EnableProcessor",
+                request_serializer=document_processor_service.EnableProcessorRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["enable_processor"]
+
+    @property
+    def disable_processor(
+        self,
+    ) -> Callable[
+        [document_processor_service.DisableProcessorRequest], operations_pb2.Operation
+    ]:
+        r"""Return a callable for the disable processor method over gRPC.
+
+        Disables a processor
+
+        Returns:
+            Callable[[~.DisableProcessorRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "disable_processor" not in self._stubs:
+            self._stubs["disable_processor"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1beta3.DocumentProcessorService/DisableProcessor",
+                request_serializer=document_processor_service.DisableProcessorRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["disable_processor"]
+
     @property
     def review_document(
         self,
