@@ -17,6 +17,9 @@ import proto  # type: ignore
 
 from google.cloud.documentai_v1beta3.types import document as gcd_document
 from google.cloud.documentai_v1beta3.types import document_io
+from google.cloud.documentai_v1beta3.types import operation_metadata
+from google.cloud.documentai_v1beta3.types import processor as gcd_processor
+from google.cloud.documentai_v1beta3.types import processor_type
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
 
@@ -30,10 +33,22 @@ __protobuf__ = proto.module(
         "BatchProcessRequest",
         "BatchProcessResponse",
         "BatchProcessMetadata",
+        "FetchProcessorTypesRequest",
+        "FetchProcessorTypesResponse",
+        "ListProcessorsRequest",
+        "ListProcessorsResponse",
+        "CreateProcessorRequest",
+        "DeleteProcessorRequest",
+        "DeleteProcessorMetadata",
+        "EnableProcessorRequest",
+        "EnableProcessorResponse",
+        "EnableProcessorMetadata",
+        "DisableProcessorRequest",
+        "DisableProcessorResponse",
+        "DisableProcessorMetadata",
         "ReviewDocumentRequest",
         "ReviewDocumentResponse",
         "ReviewDocumentOperationMetadata",
-        "CommonOperationMetadata",
     },
 )
 
@@ -258,8 +273,183 @@ class BatchProcessMetadata(proto.Message):
     )
 
 
+class FetchProcessorTypesRequest(proto.Message):
+    r"""Request message for fetch processor types.
+    Attributes:
+        parent (str):
+            Required. The project of processor type to
+            list. Format:
+            projects/{project}/locations/{location}
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+
+
+class FetchProcessorTypesResponse(proto.Message):
+    r"""Response message for fetch processor types.
+    Attributes:
+        processor_types (Sequence[google.cloud.documentai_v1beta3.types.ProcessorType]):
+            The list of processor types.
+    """
+
+    processor_types = proto.RepeatedField(
+        proto.MESSAGE, number=1, message=processor_type.ProcessorType,
+    )
+
+
+class ListProcessorsRequest(proto.Message):
+    r"""Request message for list all processors belongs to a project.
+    Attributes:
+        parent (str):
+            Required. The parent (project and location)
+            which owns this collection of Processors.
+            Format: projects/{project}/locations/{location}
+        page_size (int):
+            The maximum number of processors to return.
+            If unspecified, at most 50 processors will be
+            returned. The maximum value is 100; values above
+            100 will be coerced to 100.
+        page_token (str):
+            We will return the processors sorted by
+            creation time. The page token will point to the
+            next processor.
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+
+
+class ListProcessorsResponse(proto.Message):
+    r"""Response message for list processors.
+    Attributes:
+        processors (Sequence[google.cloud.documentai_v1beta3.types.Processor]):
+            The list of processors.
+        next_page_token (str):
+            Points to the next processor, otherwise
+            empty.
+    """
+
+    @property
+    def raw_page(self):
+        return self
+
+    processors = proto.RepeatedField(
+        proto.MESSAGE, number=1, message=gcd_processor.Processor,
+    )
+    next_page_token = proto.Field(proto.STRING, number=2,)
+
+
+class CreateProcessorRequest(proto.Message):
+    r"""Request message for create a processor. Notice this request
+    is sent to a regionalized backend service, and if the processor
+    type is not available on that region, the creation will fail.
+
+    Attributes:
+        parent (str):
+            Required. The parent (project and location)
+            under which to create the processor. Format:
+            projects/{project}/locations/{location}
+        processor (google.cloud.documentai_v1beta3.types.Processor):
+            Required. The processor to be created, requires
+            [processor_type] and [display_name] to be set. Also, the
+            processor is under CMEK if CMEK fields are set.
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+    processor = proto.Field(proto.MESSAGE, number=2, message=gcd_processor.Processor,)
+
+
+class DeleteProcessorRequest(proto.Message):
+    r"""Request message for the delete processor method.
+    Attributes:
+        name (str):
+            Required. The processor resource name to be
+            deleted.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
+class DeleteProcessorMetadata(proto.Message):
+    r"""The long running operation metadata for delete processor
+    method.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    common_metadata = proto.Field(
+        proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
+    )
+
+
+class EnableProcessorRequest(proto.Message):
+    r"""Request message for the enable processor method.
+    Attributes:
+        name (str):
+            Required. The processor resource name to be
+            enabled.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
+class EnableProcessorResponse(proto.Message):
+    r"""Response message for the enable processor method.    """
+
+
+class EnableProcessorMetadata(proto.Message):
+    r"""The long running operation metadata for enable processor
+    method.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    common_metadata = proto.Field(
+        proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
+    )
+
+
+class DisableProcessorRequest(proto.Message):
+    r"""Request message for the disable processor method.
+    Attributes:
+        name (str):
+            Required. The processor resource name to be
+            disabled.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
+class DisableProcessorResponse(proto.Message):
+    r"""Response message for the disable processor method.    """
+
+
+class DisableProcessorMetadata(proto.Message):
+    r"""The long running operation metadata for disable processor
+    method.
+
+    Attributes:
+        common_metadata (google.cloud.documentai_v1beta3.types.CommonOperationMetadata):
+            The basic metadata of the long running
+            operation.
+    """
+
+    common_metadata = proto.Field(
+        proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
+    )
+
+
 class ReviewDocumentRequest(proto.Message):
     r"""Request message for review document method.
+    Next Id: 6.
+
     Attributes:
         inline_document (google.cloud.documentai_v1beta3.types.Document):
             An inline document proto.
@@ -269,13 +459,25 @@ class ReviewDocumentRequest(proto.Message):
             reviewed with.
         document (google.cloud.documentai_v1beta3.types.Document):
             The document that needs human review.
+        enable_schema_validation (bool):
+            Whether the validation should be performed on
+            the ad-hoc review request.
+        priority (google.cloud.documentai_v1beta3.types.ReviewDocumentRequest.Priority):
+            The priority of the human review task.
     """
 
+    class Priority(proto.Enum):
+        r"""The priority level of the human review task."""
+        DEFAULT = 0
+        URGENT = 1
+
     inline_document = proto.Field(
         proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
     )
     human_review_config = proto.Field(proto.STRING, number=1,)
     document = proto.Field(proto.MESSAGE, number=2, message=gcd_document.Document,)
+    enable_schema_validation = proto.Field(proto.BOOL, number=3,)
+    priority = proto.Field(proto.ENUM, number=5, enum=Priority,)
 
 
 class ReviewDocumentResponse(proto.Message):
@@ -323,37 +525,8 @@ class ReviewDocumentOperationMetadata(proto.Message):
     create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
     update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
     common_metadata = proto.Field(
-        proto.MESSAGE, number=5, message="CommonOperationMetadata",
+        proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
     )
 
 
-class CommonOperationMetadata(proto.Message):
-    r"""The common metadata for long running operations.
-    Attributes:
-        state (google.cloud.documentai_v1beta3.types.CommonOperationMetadata.State):
-            The state of the operation.
-        state_message (str):
-            A message providing more details about the
-            current state of processing.
-        create_time (google.protobuf.timestamp_pb2.Timestamp):
-            The creation time of the operation.
-        update_time (google.protobuf.timestamp_pb2.Timestamp):
-            The last update time of the operation.
-    """
-
-    class State(proto.Enum):
-        r"""State of the longrunning operation."""
-        STATE_UNSPECIFIED = 0
-        RUNNING = 1
-        CANCELLING = 2
-        SUCCEEDED = 3
-        FAILED = 4
-        CANCELLED = 5
-
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    state_message = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
-
-
 __all__ = tuple(sorted(__protobuf__.manifest))
